Shape
=====

.. toctree::

   combinations <shape/combinations>
   exporters <shape/exporters>
   features <shape/features>
   importers <shape/importers>
   primitives <shape/primitives>
   topologies <shape/topologies>
   transformations <shape/transformations>
   types <shape/types>
